@@ -26,7 +26,7 @@ The following export tags exist:
 package Convert::Scalar;
 
 BEGIN {
-   $VERSION = '1.1';
+   $VERSION = 1.11;
    @ISA = qw(Exporter);
    @EXPORT_OK = qw(readonly readonly_on readonly_off weaken unmagic len grow extend);
    %EXPORT_TAGS = (
@@ -175,7 +175,7 @@ use this module in this case.
 =item refcnt_rv scalar[, newrefcnt]
 
 Works like C<refcnt>, but dereferences the given reference first. This is
-useful to find the reference count of arrays or hashes, which cnanot be
+useful to find the reference count of arrays or hashes, which cannot be
 passed directly. Remember that taking a reference of some object increases
 it's reference count, so the reference count used by the C<*_rv>-functions
 tend to be one higher.
@@ -203,10 +203,6 @@ Works like C<refcnt_dec>, but dereferences the given reference first.
 Calls SvOK, SvUOK, SvROK, SvPOK, SvNOK or SvNIOK on the given scalar,
 respectively.
 
-=cut
-
-1;
-
 =back
 
 =head2 CANDIDATES FOR FUTURE RELEASES
@@ -226,3 +222,5 @@ inclusion in this module If you want them, write me.
 
 =cut
 
+1
+
